@@ -562,6 +562,54 @@ biff_format_data_destroy (gpointer key, BIFF_FORMAT_DATA *d, gpointer userdata)
 	return 1 ;
 }
 
+typedef struct {
+	guint16 idx ;
+	char *name ;
+	guint8 *formula ;
+	guint16 formula_len ;
+} BIFF_NAME_DATA ;
+
+/**
+ * A copy of name is kept but
+ * formula is g_malloc'd and copied
+ **/
+static void
+biff_name_data_new (MS_EXCEL_SHEET *sheet, char *name, guint8 *formula, guint16 len)
+{
+	BIFF_NAME_DATA *bnd = g_new (BIFF_NAME_DATA, 1) ;
+	bnd->idx = g_hash_table_size (sheet->wb->name_data) + 1 ;
+	bnd->name = name ;
+	if (formula) {
+		bnd->formula = g_new (guint8, len) ;
+		memcpy (bnd->formula, formula, len) ;
+		bnd->formula_len = len ;
+	} else {
+		bnd->formula = 0 ;
+		bnd->formula_len = 0 ;
+	}
+	g_hash_table_insert (sheet->wb->name_data, &bnd->idx, bnd) ;
+/*	printf ("Inserting '%s' into externname table at (%d)\n", bnd->name, bnd->idx) ; */
+}
+
+char *
+biff_name_data_get_name (MS_EXCEL_SHEET *sheet, guint16 idx)
+{
+	BIFF_NAME_DATA *ptr = g_hash_table_lookup (sheet->wb->name_data, &idx) ;
+	if (ptr)
+		return ptr->name ;
+	else
+		return 0 ;
+}
+
+static gboolean 
+biff_name_data_destroy (gpointer key, BIFF_NAME_DATA *bnd, gpointer userdata)
+{
+	g_free (bnd->name) ;
+	g_free (bnd->formula) ;
+	g_free (bnd) ;
+	return 1 ;
+}
+
 static MS_EXCEL_PALETTE *
 ms_excel_palette_new (BIFF_QUERY * q)
 {
@@ -1081,6 +1129,8 @@ ms_excel_workbook_new ()
 						 (GCompareFunc)biff_guint16_equal) ;
 	ans->format_data = g_hash_table_new ((GHashFunc)biff_guint16_hash,
 					     (GCompareFunc)biff_guint16_equal) ;
+	ans->name_data = g_hash_table_new ((GHashFunc)biff_guint16_hash,
+					   (GCompareFunc)biff_guint16_equal) ;
 	ans->palette = NULL;
 	ans->global_strings = NULL;
 	ans->global_string_max = 0;
@@ -1162,7 +1212,12 @@ ms_excel_workbook_destroy (MS_EXCEL_WORKBOOK * wb)
 	g_hash_table_foreach_remove (wb->format_data,
 				     (GHRFunc)biff_format_data_destroy,
 				     wb) ;
-	g_hash_table_destroy (wb->font_data) ;
+	g_hash_table_destroy (wb->format_data) ;
+
+	g_hash_table_foreach_remove (wb->name_data,
+				     (GHRFunc)biff_name_data_destroy,
+				     wb) ;
+	g_hash_table_destroy (wb->name_data) ;
 
 	if (wb->palette)
 		ms_excel_palette_destroy (wb->palette);
@@ -1251,22 +1306,10 @@ ms_excel_read_cell (BIFF_QUERY * q, MS_EXCEL_SHEET * sheet)
 				row = EX_GETROW (q);
 				col = EX_GETCOL (q);
 				ptr = (q->data + 4);
-				lastcol = BIFF_GETWORD (q->data + q->length - 2);	/*
-											 * guess 
-											 */
+				lastcol = BIFF_GETWORD (q->data + q->length - 2);
 /*				printf ("Cells in row %d are blank starting at col %d until col %d (0x%x)\n",
 				row, col, lastcol, lastcol); */
-				/*
-				 * if (lastcol<col)  What to do in this case ? 
-				 * {
-				 * printf ("Serious implentation documentation error\n");
-				 * break;
-				 * }
-				 */
 				incr = (lastcol > col) ? 1 : -1;
-				/*
-				 * g_assert (((lastcol-col)*incr+1)*2+6<=q->length); 
-				 */
 				while (col != lastcol){
 					ms_excel_sheet_insert (sheet, BIFF_GETWORD (ptr), EX_GETCOL (q), EX_GETROW (q), 0);
 					col += incr;
@@ -1280,9 +1323,11 @@ ms_excel_read_cell (BIFF_QUERY * q, MS_EXCEL_SHEET * sheet)
 		char *str ;
 		if (q->length)
 		{
-			printf ("Header '%s'\n", (str=biff_get_text (q->data+1,
-								     BIFF_GETBYTE(q->data)))) ;
-			g_free(str) ;
+			if (EXCEL_DEBUG>0) {
+				printf ("Header '%s'\n", (str=biff_get_text (q->data+1,
+									     BIFF_GETBYTE(q->data)))) ;
+				g_free(str) ;
+			}
 		}
  		break;
 	}
@@ -1291,9 +1336,11 @@ ms_excel_read_cell (BIFF_QUERY * q, MS_EXCEL_SHEET * sheet)
 		char *str ;
 		if (q->length)
 		{
-			printf ("Footer '%s'\n", (str=biff_get_text (q->data+1,
+			if (EXCEL_DEBUG>0) {
+				printf ("Footer '%s'\n", (str=biff_get_text (q->data+1,
 								     BIFF_GETBYTE(q->data)))) ;
-			g_free(str) ;
+				g_free(str) ;
+			}
 		}
  		break;
 	}
@@ -1327,11 +1374,28 @@ ms_excel_read_cell (BIFF_QUERY * q, MS_EXCEL_SHEET * sheet)
 		}
 	case BIFF_COLINFO: /* FIXME: See: S59D67.HTM */
 	{
+		int firstcol, lastcol, width, lp ;
+		guint16 cols_xf, options ;
+		int hidden, collapsed, outlining ;
+		firstcol = BIFF_GETWORD(q->data) ;
+		lastcol  = BIFF_GETWORD(q->data+2) ;
+		width    = BIFF_GETWORD(q->data+4) ;
+		cols_xf  = BIFF_GETWORD(q->data+6) ;
+		options  = BIFF_GETWORD(q->data+8) ;
+		
+		hidden    = (options & 0x0001) != 0 ;
+		collapsed = (options & 0x1000) != 0 ;
+		outlining = (options & 0x0700) >> 8 ;
+
+		if (EXCEL_DEBUG>0 && BIFF_GETBYTE(q->data+10) != 0)
+			printf ("Odd Colinfo\n") ;
+		printf ("Column Formatting from col %d to %d of width %f characters\n",
+			firstcol, lastcol, width/256.0) ;
+		for (lp=firstcol;lp<=lastcol;lp++)
+			sheet_col_set_width (sheet->gnum_sheet, lp, width/25) ;
 		break ;
 	}
-	case BIFF_RK:		/*
-				 * FIXME: S59DDA.HTM - test IEEE stuff on other endian platforms 
-				 */
+	case BIFF_RK: /* See: S59DDA.HTM */
 	{
 		char buf[65];
 		
@@ -1376,23 +1440,46 @@ ms_excel_read_cell (BIFF_QUERY * q, MS_EXCEL_SHEET * sheet)
 	case BIFF_ROW: /* FIXME: See: S59DDB.HTM */
 	{
 		guint16 height = BIFF_GETWORD(q->data+6) ;
-		printf ("Row %d formatting 0x%x\n", BIFF_GETWORD(q->data), height); 
+/*		printf ("Row %d formatting 0x%x\n", BIFF_GETWORD(q->data), height);  */
 		if ((height&0x8000) == 0) /* Fudge Factor */
-			sheet_row_set_height (sheet->gnum_sheet, BIFF_GETWORD(q->data), BIFF_GETWORD(q->data+6)/10, TRUE) ;
+		{
+/*			printf ("Row height : %f points\n", BIFF_GETWORD(q->data+6)/20.0) ;*/
+			sheet_row_set_height (sheet->gnum_sheet, BIFF_GETWORD(q->data), BIFF_GETWORD(q->data+6)/15, TRUE) ;
+		}
 		break;
 	}
-	case BIFF_ARRAY:	/*
-				 * FIXME: S59D57.HTM 
-				 */
+	case BIFF_ARRAY: /* See: S59D57.HTM */
+	{
+		int array_col_first, array_col_last ;
+		int array_row_first, array_row_last ;
+		int xlp, ylp ;
+
+		array_row_first = BIFF_GETWORD(q->data + 0) ;
+		array_row_last  = BIFF_GETWORD(q->data + 2) ;
+		array_col_first = BIFF_GETBYTE(q->data + 4) ;
+		array_col_last  = BIFF_GETBYTE(q->data + 5) ;
+
 		printf ("Array Formula\n") ;
-	case BIFF_FORMULA:	/*
-				 * FIXME: S59D8F.HTM 
-				 */
-		/*
-		 * case BIFF_NAME FIXME: S59DA9.HTM 
-		 */
-		ms_excel_parse_formula (sheet, q, EX_GETCOL (q), EX_GETROW (q));
+		for (xlp=array_col_first;xlp<=array_col_last;xlp++)
+			for (ylp=array_row_first;ylp<=array_row_last;ylp++)
+			{
+				char *txt = ms_excel_parse_formula (sheet, (q->data + 14),
+								    xlp, ylp, BIFF_GETWORD(q->data+12)) ;
+				/* FIXME: Magic XF number: 0 */
+				ms_excel_sheet_insert (sheet, 0, xlp, ylp, txt) ;
+				g_free(txt) ;
+			}
+		break ;
+	}
+	case BIFF_FORMULA: /* See: S59D8F.HTM */
+	{
+		char *txt = ms_excel_parse_formula (sheet, (q->data + 22),
+						    EX_GETCOL (q), EX_GETROW (q),
+						    BIFF_GETWORD(q->data+20));
+		ms_excel_sheet_insert (sheet, EX_GETXF(q), EX_GETCOL(q), EX_GETROW(q), txt) ;
+		g_free (txt) ;
 		break;
+	}
 	case BIFF_LABELSST:
 	{
 		char *str;
@@ -1407,6 +1494,38 @@ ms_excel_read_cell (BIFF_QUERY * q, MS_EXCEL_SHEET * sheet)
 		}
                 break;
 	}
+
+	case BIFF_EXTERNNAME: /* FIXME: S59D7E.HTM */
+	{
+		char *externname ;
+		if ( sheet->ver >= eBiffV7) {
+			guint16 options  = BIFF_GETWORD(q->data) ;
+			guint8  namelen  = BIFF_GETBYTE(q->data+6) ;
+			guint16 defnlen  = BIFF_GETWORD(q->data + 7 + namelen) ;
+			char *definition = 0 ;
+			
+			externname = biff_get_text (q->data+7, namelen) ;
+			if ((options & 0xffe0) != 0) {
+				printf ("Duff externname\n") ; break ;
+			}
+			if ((options & 0x0001) != 0)
+				printf ("fBuiltin\n") ;
+			/* Copy the definition to storage to parse at run-time in the formula */
+			biff_name_data_new (sheet, externname, definition, defnlen) ;
+		} else { /* Ancient Papyrus spec. */
+			guint8 data[] = { 0x1c, 0x17 } ;
+			printf ("Externname Data:\n") ;
+			dump (q->data, q->length) ;
+			externname = biff_get_text (q->data+1, BIFF_GETBYTE(q->data)) ;
+			biff_name_data_new (sheet, externname, data, 2) ;
+		}
+		if (EXCEL_DEBUG>1)
+		{
+			printf ("Externname '%s'\n", externname) ;
+			dump (q->data, q->length) ;
+		}
+		break ;
+	}
 	default:
 		switch (q->opcode)
 		{
@@ -1465,8 +1584,11 @@ ms_excel_read_cell (BIFF_QUERY * q, MS_EXCEL_SHEET * sheet)
 		case BIFF_STRING: /* FIXME: S59DE9.HTM */
 		{
 			char *txt ;
-			printf ("This cell evaluated to '%s': so what ? data:\n", (txt = biff_get_text (q->data + 2, BIFF_GETWORD(q->data)))) ;
-			if (txt) g_free (txt) ;
+			if (EXCEL_DEBUG>0)
+			{
+				printf ("This cell evaluated to '%s': so what ? data:\n", (txt = biff_get_text (q->data + 2, BIFF_GETWORD(q->data)))) ;
+				if (txt) g_free (txt) ;
+			}
 			break ;
 		}
 		case BIFF_BOOLERR: /* S59D5F.HTM */
@@ -1561,8 +1683,8 @@ find_workbook (MS_OLE * ptr)
 		/*
 		 * printf ("Checking '%s'\n", d->name); 
 		 */
-		hit |= (strncasecmp (d->name, "book", 4) == 0);
-		hit |= (strncasecmp (d->name, "workbook", 8) == 0);
+		hit |= (g_strncasecmp (d->name, "book", 4) == 0);
+		hit |= (g_strncasecmp (d->name, "workbook", 8) == 0);
 		if (hit) {
 			MS_OLE_STREAM *stream ;
 			printf ("Found Excel Stream : %s\n", d->name);
