@@ -382,56 +382,6 @@ gnumeric_ceil (struct FunctionDefinition *i, Value *argv [], char **error_string
 	return value_float (ceil (value_get_as_double (argv [0])));
 }
 
-static char *help_bin2dec = {
-	N_("@FUNCTION=BIN2DEC\n"
-	   "@SYNTAX=BIN2DEC(x)\n"
-
-	   "@DESCRIPTION="
-	   "The BIN2DEC function converts a binary number "
-	   "in string or number to its decimal equivalent."
-	   "\n"
-
-	   "Performing this function on a string or empty cell simply does nothing."
-	   "\n"
-	   "@SEEALSO=DEC2BIN")
-};
-
-static Value *
-gnumeric_bin2dec (struct FunctionDefinition *i, Value *argv [], char **error_string)
-{
-	int  result, v, n, bit;
-	char *p;
-
-	result = 0;
-	switch (argv [0]->type){
-	case VALUE_INTEGER:
-		v = argv [0]->v.v_int;
-		n = 0;
-		for (n = 0; v; n++){
-			bit = v % 10;
-			v   = v / 10;
-			result |= bit << n;
-		}
-		break;
-		
-	case VALUE_STRING:
-		p = argv [0]->v.str->str;
-		for (;*p; p++){
-			if (!(*p == '0' || *p == '1')){
-				*error_string = "#NUM!";
-				return NULL;
-			}
-			result = result << 1 | (*p - '0');
-		}
-		break;
-		
-	default:
-		*error_string = "#NUM!";
-		return NULL;
-	}
-	return value_int (result);
-}
-
 static char *help_cos = {
 	N_("@FUNCTION=COS\n"
 	   "@SYNTAX=COS(x)\n"
@@ -1027,6 +977,30 @@ gnumeric_sinh (struct FunctionDefinition *i, Value *argv [], char **error_string
 	return value_float (sinh (value_get_as_double (argv [0])));
 }
 
+static char *help_sqrt = {
+	N_("@FUNCTION=SQRT\n"
+	   "@SYNTAX=SQRT(x)\n"
+
+	   "@DESCRIPTION="
+	   "The SQRT  function  returns  the  square root of x, "
+	   "\n"
+	   "If x is negative returns #NUM!."
+	   "This function only takes one argument."
+	   "\n"
+	   "@SEEALSO=POW")
+};
+
+static Value *
+gnumeric_sqrt (struct FunctionDefinition *i, Value *argv [], char **error_string)
+{
+	float_t x = value_get_as_double (argv[0]) ;
+	if (x<0) {
+		*error_string = _("#NUM!") ;
+		return NULL ;
+	}
+	return value_float (sqrt(x)) ;
+}
+
 static char *help_sum = {
 	N_("@FUNCTION=SUM\n"
 	   "@SYNTAX=SUM(value1, value2, ...)\n"
@@ -1046,9 +1020,32 @@ callback_function_sum (Sheet *sheet, Value *value, char **error_string, void *cl
 
 	switch (value->type){
 	case VALUE_INTEGER:
-		if (result->type == VALUE_INTEGER)
-			result->v.v_int += value->v.v_int;
-		else
+		if (result->type == VALUE_INTEGER){
+			if ((result->v.v_int > 0) && (value->v.v_int > 0)){
+				int sum = result->v.v_int + value->v.v_int;
+
+				if (sum < result->v.v_int){
+					double n = result->v.v_int + value->v.v_int;
+					
+					result->type = VALUE_FLOAT;
+					result->v.v_float = n;
+				} else
+					result->v.v_int = sum;
+			} else if ((result->v.v_int < 0) && (value->v.v_int < 0)){
+				int sum = result->v.v_int + value->v.v_int;
+
+				if (sum > result->v.v_int){
+					double n = result->v.v_int + value->v.v_int;
+					
+					result->type = VALUE_FLOAT;
+					result->v.v_float = n;
+				} else {
+					result->v.v_int = sum;
+				}
+			} else {
+				result->v.v_int += value->v.v_int;
+			}
+		} else
 			result->v.v_float += value->v.v_int;
 		break;
 		
@@ -1218,11 +1215,6 @@ FunctionDefinition math_functions [] = {
 	{ "atan2",   "ff",   "xnum,ynum", &help_atan2, NULL, gnumeric_atan2 },
 	/* avedev */
 	{ "average", 0,      "",          &help_average, gnumeric_average, NULL },
-	/* besseli */
-	/* besselj */
-	/* besselk */
-	/* bessely */
-	{ "bin2dec", "?",    "number",    &help_bin2dec, NULL, gnumeric_bin2dec },
 	{ "cos",     "f",    "number",    &help_cos,     NULL, gnumeric_cos },
 	{ "cosh",    "f",    "number",    &help_cosh,    NULL, gnumeric_cosh },
 	{ "count",   0,      "",          &help_count,   gnumeric_count, NULL },
@@ -1243,6 +1235,7 @@ FunctionDefinition math_functions [] = {
 	{ "radians", "f",    "number",    &help_radians, NULL, gnumeric_radians },
 	{ "sin",     "f",    "number",    &help_sin,     NULL, gnumeric_sin },
 	{ "sinh",    "f",    "number",    &help_sinh,    NULL, gnumeric_sinh },
+	{ "sqrt",    "f",    "number",    &help_sqrt,    NULL, gnumeric_sqrt },
 	{ "sum",     0,      "number",    &help_sum,     gnumeric_sum, NULL },
 	{ "tan",     "f",    "number",    &help_tan,     NULL, gnumeric_tan },
 	{ "tanh",    "f",    "number",    &help_tanh,    NULL, gnumeric_tanh },
