@@ -1,5 +1,5 @@
-#ifndef ITEM_BAR_H
-#define ITEM_BAR_H
+#ifndef GNUMERIC_ITEM_BAR_H
+#define GNUMERIC_ITEM_BAR_H
 
 #define ITEM_BAR(obj)          (GTK_CHECK_CAST((obj), item_bar_get_type (), ItemBar))
 #define ITEM_BAR_CLASS(k)      (GTK_CHECK_CLASS_CAST ((k), item_bar_get_type ()))
@@ -7,6 +7,12 @@
 
 #define ITEM_BAR_RESIZING(x) (ITEM_BAR(x)->resize_pos != -1)
 
+typedef enum {
+	ITEM_BAR_NO_SELECTION,
+	ITEM_BAR_PARTIAL_SELECTION,
+	ITEM_BAR_FULL_SELECTION
+} ItemBarSelectionType;
+
 typedef struct {
 	GnomeCanvasItem canvas_item;
 	SheetView       *sheet_view;
@@ -36,8 +42,8 @@ typedef struct {
 	GnomeCanvasItemClass parent_class;
 
 	/* Signals emited */
-	void (* selection_changed) (ItemBar *, int column, int reset);
+	void (* selection_changed) (ItemBar *, int column, int modifiers);
 	void (* size_changed)      (ItemBar *, int column, int new_width);
 } ItemBarClass;
 
-#endif
+#endif /* GNUMERIC_ITEM_BAR_H */
